# Generated by roxygen2: do not edit by hand

S3method(plot,exploded_map)
S3method(plot,grouped_exploded_map)
S3method(print,exploded_map)
S3method(print,grouped_exploded_map)
S3method(summary,exploded_map)
S3method(summary,grouped_exploded_map)
export(cache_clear)
export(cache_list)
export(calibration_row)
export(compute_stats)
export(derive_params)
export(estimate_block_radii)
export(explode_grouped)
export(explode_section)
export(explode_sf)
export(explode_sf_with_lookup)
export(explode_state)
export(export_topojson)
export(focus_map)
export(focus_map_preset)
export(focusmapOutput)
export(layout_regions)
export(renderFocusmap)
importFrom(rlang,":=")
importFrom(rlang,.data)
