#' explodemap: Hierarchical Exploded-View Cartography
#'
#' Internal package declarations for NSE checks.
#'
#' @keywords internal
#' @importFrom rlang .data :=
"_PACKAGE"

## usethis namespace: start
#' @importFrom rlang .data
## usethis namespace: end
NULL
