% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tiger.R
\name{cache_list}
\alias{cache_list}
\title{List cached datasets}
\usage{
cache_list()
}
\value{
Invisibly returns a character vector of cached \code{.rds} file names.
The visible output is a message listing the cache directory and file sizes,
or a message that the cache is empty.
}
\description{
List cached datasets
}
