% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tiger.R
\name{.attach_regions_tiger}
\alias{.attach_regions_tiger}
\title{Attach region labels to TIGER/Line data via county names}
\usage{
.attach_regions_tiger(sf_obj, fips, region_map, quiet = FALSE)
}
\description{
Attach region labels to TIGER/Line data via county names
}
\keyword{internal}
