% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot.R
\name{.make_plots}
\alias{.make_plots}
\title{Build standard original/exploded ggplot pair}
\usage{
.make_plots(sf_orig, sf_exp, region_col, title, params)
}
\description{
Build standard original/exploded ggplot pair
}
\keyword{internal}
