% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{calibration_row}
\alias{calibration_row}
\title{Extract calibration row from an exploded_map}
\usage{
calibration_row(x)
}
\arguments{
\item{x}{An \code{exploded_map} object}
}
\value{
A one-row data.frame
}
\description{
Returns a one-row data.frame suitable for binding across datasets
to build a calibration table.
}
