% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/grouped.R
\name{.make_grouped_plots}
\alias{.make_grouped_plots}
\title{Build plots for grouped layouts}
\usage{
.make_grouped_plots(sf_orig, sf_local, sf_grouped, region_col, title, params)
}
\description{
Build plots for grouped layouts
}
\keyword{internal}
