% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/export.R
\name{.as_export_sf}
\alias{.as_export_sf}
\title{Normalize input to an export-ready sf object in WGS84}
\usage{
.as_export_sf(x)
}
\arguments{
\item{x}{An sf, exploded_map, or grouped_exploded_map object}
}
\value{
sf object
}
\description{
Normalize input to an export-ready sf object in WGS84
}
\keyword{internal}
