% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tiger.R
\name{cache_clear}
\alias{cache_clear}
\title{Clear explodemap download cache}
\usage{
cache_clear(key = NULL)
}
\arguments{
\item{key}{Specific cache key to clear, or NULL to clear all}
}
\value{
Invisibly returns \code{NULL}. The function is called for its side effect
of deleting cached \code{.rds} files and reporting what was removed.
}
\description{
Clear explodemap download cache
}
