% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/export.R
\name{.build_mapshaper_args}
\alias{.build_mapshaper_args}
\title{Build mapshaper CLI arguments}
\usage{
.build_mapshaper_args(input, output, simplify = NULL)
}
\arguments{
\item{input}{Path to input GeoJSON file}

\item{output}{Path to output TopoJSON file}

\item{simplify}{Optional simplification proportion in \verb{(0, 1)}.}
}
\value{
Character vector of arguments for system2()
}
\description{
Build mapshaper CLI arguments
}
\keyword{internal}
