% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/api.R
\name{.handle_export}
\alias{.handle_export}
\title{Handle export logic}
\usage{
.handle_export(export, sf_exp_wgs, label)
}
\description{
Handle export logic
}
\keyword{internal}
