% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{print.exploded_map}
\alias{print.exploded_map}
\title{Print an exploded_map object}
\usage{
\method{print}{exploded_map}(x, ...)
}
\arguments{
\item{x}{An \code{exploded_map} object}

\item{...}{Ignored}
}
\value{
Invisibly returns \code{x}, the original \code{exploded_map} object. The
method is called for its side effect of printing a compact diagnostic
overview of units, regions, derived parameters, and optional refinement
information.
}
\description{
Print an exploded_map object
}
