% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tiger.R
\name{.download_cousub}
\alias{.download_cousub}
\title{Download TIGER/Line county subdivision boundaries}
\usage{
.download_cousub(fips, crs)
}
\arguments{
\item{fips}{2-digit state FIPS code}

\item{crs}{Target projected CRS}
}
\value{
sf object
}
\description{
Download TIGER/Line county subdivision boundaries
}
\keyword{internal}
