% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/explodemap-package.R
\docType{package}
\name{explodemap-package}
\alias{explodemap}
\alias{explodemap-package}
\title{explodemap: Hierarchical Exploded-View Cartography}
\description{
Internal package declarations for NSE checks.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://prigasg.github.io/explodemap/}
  \item \url{https://github.com/PrigasG/explodemap}
  \item Report bugs at \url{https://github.com/PrigasG/explodemap/issues}
}

}
\author{
\strong{Maintainer}: George Arthur \email{prigasgenthian48@gmail.com}

}
\keyword{internal}
