% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{summary.grouped_exploded_map}
\alias{summary.grouped_exploded_map}
\title{Summary of a grouped_exploded_map object}
\usage{
\method{summary}{grouped_exploded_map}(object, ...)
}
\arguments{
\item{object}{A \code{grouped_exploded_map} object}

\item{...}{Ignored}
}
\value{
Invisibly returns \code{object}, the original \code{grouped_exploded_map}
object. The method is called for its side effect of printing dataset size,
grouping diagnostics, anchor parameters, and anchor radii.
}
\description{
Summary of a grouped_exploded_map object
}
