% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/grouped.R
\name{.generate_anchors}
\alias{.generate_anchors}
\title{Generate initial radial anchors from the national centroid}
\usage{
.generate_anchors(
  block_df,
  nat_centroid,
  kappa = 1.8,
  padding = 50000,
  delta = 15000
)
}
\description{
Generate initial radial anchors from the national centroid
}
\keyword{internal}
