% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tiger.R
\name{.get_national_counties}
\alias{.get_national_counties}
\title{Download national county name-to-FIPS lookup}
\usage{
.get_national_counties()
}
\description{
Download national county name-to-FIPS lookup
}
\keyword{internal}
