% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{plot.exploded_map}
\alias{plot.exploded_map}
\title{Plot an exploded_map object}
\usage{
\method{plot}{exploded_map}(x, which = c("exploded", "original", "both"), ...)
}
\arguments{
\item{x}{An \code{exploded_map} object}

\item{which}{"exploded" (default), "original", or "both"}

\item{...}{Ignored}
}
\value{
Invisibly returns \code{x}, the original \code{exploded_map} object. The
method is called for its side effect of drawing the stored \code{ggplot2}
original and/or exploded map objects.
}
\description{
Plot an exploded_map object
}
