% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/grouped.R
\name{.refine_anchors}
\alias{.refine_anchors}
\title{Refine anchors with pairwise repulsion plus spring return}
\usage{
.refine_anchors(
  block_df,
  lambda = 0.18,
  eta = 0.18,
  padding_sep = 20000,
  max_iter = 60
)
}
\description{
Refine anchors with pairwise repulsion plus spring return
}
\keyword{internal}
