% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/export.R
\name{.find_mapshaper}
\alias{.find_mapshaper}
\title{Locate the mapshaper executable on the system path}
\usage{
.find_mapshaper()
}
\value{
Path to mapshaper executable
}
\description{
Locate the mapshaper executable on the system path
}
\keyword{internal}
