% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{plot.grouped_exploded_map}
\alias{plot.grouped_exploded_map}
\title{Plot a grouped_exploded_map object}
\usage{
\method{plot}{grouped_exploded_map}(x, which = c("grouped", "original", "local", "all"), ...)
}
\arguments{
\item{x}{A \code{grouped_exploded_map} object}

\item{which}{"grouped" (default), "original", "local", or "all"}

\item{...}{Ignored}
}
\value{
Invisibly returns \code{x}, the original \code{grouped_exploded_map} object.
The method is called for its side effect of drawing the stored \code{ggplot2}
grouped, original, and/or local map objects.
}
\description{
Plot a grouped_exploded_map object
}
